@@ -20,9 +20,8 @@ sub new {
 
 # sub warn {
 	# my $self = shift;
-	# my $message = shift;
 #
-	# ::diag($message);
+	# ::diag(@_);
 # }
 
 # sub info {
@@ -34,10 +33,9 @@ sub new {
 
 sub trace {
 	my $self = shift;
-	my $message = shift;
 
 	if($ENV{'TEST_VERBOSE'}) {
-		::diag($message);
+		::diag(@_);
 	}
 }
 
